package com.primeton.gateway.controller;

import com.alibaba.fastjson.JSON;
import com.primeton.gateway.model.JwtTestModel;
import com.primeton.gateway.model.User;
import io.jsonwebtoken.Jwts;
import io.jsonwebtoken.SignatureAlgorithm;
import io.jsonwebtoken.security.Keys;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.nio.charset.StandardCharsets;
import java.util.*;

@RestController
@RequestMapping(value = "/gatewayTest")
@Api(tags = "网关测试demo")
public class TestController {


    @GetMapping("/get")
    @ApiOperation("无参,返回访问成功")
    public String get() {
        System.out.println("get请求,无参返回'访问成功'");
        return "访问成功";
    }

    @GetMapping("/get/{value1}/test/{value2}/ccc")
    @ApiOperation("pathValue")
    public String get(@PathVariable String value1, @PathVariable String value2) {
        return "value1=" + value1 + "       " + "value2=" + value2;
    }

    @PostMapping("/postNoParameter")
    @ApiOperation("无参，返回sucess")
    public String postNoParameter() {
        return "Success";
    }

    @PostMapping("/post")
    @ApiOperation("带参map,返回输入的参数")
    public Map<String, Object> post(@RequestBody Map<String, Object> map) {
        System.out.println("带参map,返回输入的参数" + map);
        return map;
    }
    @PostMapping("/post1")
    public boolean post1(@RequestPart MultipartFile file) {
        System.out.println();
        return false;
    }

    @GetMapping("/returnDate")
    @ApiOperation("无参,返回当前时间")
    public String returnDate() {
        String time = String.valueOf(System.currentTimeMillis());
        return time;
    }

    @DeleteMapping("/DeleteMapping")
    @ApiOperation("带参整数,返回输入参数")
    public Integer change(@RequestParam("int") Integer num) {
        System.out.println("带参整数,返回输入参数 = " + num);
        return num;
    }

    @PostMapping("/userChange")
    @ApiOperation("带参model,返回输入实体")
    public User userChange(@RequestBody User user) {
        System.out.println("带参model,返回输入实体 = " + user);
        return user;
    }

    @PostMapping("/errors")
    @ApiOperation("异常测试用例")
    public User errors() {
        throw new RuntimeException("id=>" + "222" + ",不存在该用户,或者信息无法找到!");
    }

    @PostMapping("/errors1")
    @ApiOperation("异常测试用例")
    public User errors1() {
        throw new RuntimeException("id=>" + "222" + ",不存在该用户,或者信息无法找到!");
    }

    @PostMapping("/overtime")
    @ApiOperation("超时10秒")
    public String overtime() {
        try {
            Thread.sleep(10000);
        } catch (InterruptedException e) {
            e.printStackTrace();
            Thread.currentThread().interrupt();
        }
        return "异常超时10秒用例";
    }

    @GetMapping("/interfacePath/{pathId}")
    @ApiOperation("path携带参数")
    public String interfacePath(@PathVariable String pathId) {
        return "pathId" + ":" + pathId;
    }

    @GetMapping("/bigReq")
    @ApiOperation("gzip测试接口")
    public String bigReq() {
        List<String> reesult = new ArrayList<>(4096);
        for (int i = 0; i < 4096; i++) {
            reesult.add(UUID.randomUUID().toString());
        }
        return JSON.toJSONString(reesult);
    }

    @GetMapping("/getJwtTestModel")
    @ApiOperation("返回jwt测试案例")
    public JwtTestModel getJwtModel() {
        JwtTestModel jwtTestModel = new JwtTestModel();

        final String secreteKey = "libq001-test-jwt001-test-jwt001-test";
        Map<String, String> map = new HashMap<>();
        map.put("id", "1");
        map.put("name", "xiaoming");

        String token = Jwts.builder()
                .setClaims(map)
                .signWith(Keys.hmacShaKeyFor(secreteKey.getBytes(StandardCharsets.UTF_8)), SignatureAlgorithm.HS256)
                .compact();

        jwtTestModel.setSecretKey(secreteKey);
        jwtTestModel.setToken(token);
        jwtTestModel.setTestMap(map);

        return jwtTestModel;
    }

}
